!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
!                                          numgeo
!                Copyright (C) 2018-2023 Jan Machacek, Patrick Staubach
!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
!
! SUBROUTINE: user_contact_properties
!
!> author: Patrick Staubach, patrick.staubach@yahoo.de
!> date: 06.05.2020
!
!> Interface to user subroutine to define amplitude value
!
!>### History
!> 06.05.2020, P. Staubach - Initial version
!
!>@todo
!> After program is completed, this subroutine should be excluded again and made accessible to the
!> main program numgeo.exe as a dynamic linked library (*.so). This should be done to prevent excessive 
!> recompilation before every calculation with changed initial conditions.
!>@endtodo
!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
subroutine user_amplitude(time,nprops,props,value) bind(c,name='user_amplitude')
  use, intrinsic :: iso_c_binding
  implicit none
  real(c_double)                    , intent(in)    :: time                !! current step time 
  integer(c_int)                    , intent(in)    :: nprops              !! number of user specified properties
  real(c_double), dimension(nprops) , intent(in)    :: props               !! properties of this amplitude
  real(c_double), dimension(3)      , intent(inout) :: value               !! value of this amplitude               

  real(c_double), parameter :: pi = 3.147d0
  real(c_double), parameter :: omega = 2.0d0 * pi * 2.0d0
  real(c_double), parameter :: omega2 = 2.0d0 * pi * 10.0d0
  
  value = 0.0d0
  value(1) = time+(sin(omega*time)/5.0d0-sin(omega2*time)/20.d0)
  
end subroutine user_amplitude
